==> jc-1.4.0.tar.gz: soot/jimple/toolkits/annotation/methods/UnreachableMethodsTagger.h <==
// public class soot.jimple.toolkits.annotation.methods.UnreachableMethodsTagger

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1988ae632461b86a soot_SceneTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 2c73b247cf12309b soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger

// header file dependencies
// @dep_header soot_SceneTransformer

#include "soot/SceneTransformer.h"

#ifndef _JC_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger_H_
#define _JC_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$sub_refs	_jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$refs	_jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$nonrefs	_jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$object	_jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$vmethods	_jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$vtable	_jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$vtype	_jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$method$internalTransform$b44b61d0d9f22a06(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$object *, struct _jc_java_lang_String$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$method_info$internalTransform$b44b61d0d9f22a06;

// Static methods
extern struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$object *_jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$method$v$a448bfe7dc52356d(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$vmethods {
	void	(*internalTransform$b44b61d0d9f22a06)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_SceneTransformer$vmethods	soot_SceneTransformer;
	_jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$vmethods	soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$refs {
    _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$sub_refs	soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger;
    _jc_soot_SceneTransformer$sub_refs	soot_SceneTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_SceneTransformer$sub_nonrefs	soot_SceneTransformer;
    _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$sub_nonrefs	soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$object {
	_jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$vtype _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/annotation/methods/UnreachableMethodsTagger.h <==
// public class soot.jimple.toolkits.annotation.methods.UnreachableMethodsTagger

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1988ae632461b86a soot_SceneTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 2c73b247cf12309b soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger

// header file dependencies
// @dep_header soot_SceneTransformer

#include "soot/SceneTransformer.h"

#ifndef _JC_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger_H_
#define _JC_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$sub_refs	_jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$refs	_jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$nonrefs	_jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$object	_jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$vmethods	_jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$vtable	_jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$vtype	_jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$method$internalTransform$b44b61d0d9f22a06(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$method_info$internalTransform$b44b61d0d9f22a06;

// Static methods
extern struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$object *_jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$method$v$a448bfe7dc52356d(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$vmethods {
	void	(*internalTransform$b44b61d0d9f22a06)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_SceneTransformer$vmethods	soot_SceneTransformer;
	_jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$vmethods	soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$refs {
    _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$sub_refs	soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger;
    _jc_soot_SceneTransformer$sub_refs	soot_SceneTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_SceneTransformer$sub_nonrefs	soot_SceneTransformer;
    _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$sub_nonrefs	soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$object {
	_jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$vtype _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_methods_UnreachableMethodsTagger_H_ */
